@@ -29,7 +29,7 @@ import click
 from click import echo, style
 from click.termui import get_terminal_size
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 __author__ = "Steven Loria"
 __license__ = "MIT"
 
@@ -47,24 +47,13 @@ _BOLD_LEN = 8
 # Number of characters added by color formatting
 _COLOR_LEN = 9
 
-def print_version(ctx, param, value):
-    if not value or ctx.resilient_parsing:
-        return
-    echo(__version__)
-    ctx.exit()
-
 
 def echof(s, *args, **kwargs):
     echo(style(s, *args, **kwargs))
 
 
-@click.group()
-@click.option('--version', '-v',
-    is_flag=True,
-    callback=print_version,
-    expose_value=False,
-    is_eager=True,
-    help="Show the current pypi-cli version.")
+@click.group(context_settings={'help_option_names': ('-h', '--help')})
+@click.version_option(__version__, '--version', '-v', message='%(version)s')
 def cli():
     """The pypi CLI.
 
@@ -523,7 +512,7 @@ class Searcher(object):
 
     def score(self, tokens, record):
         score = 0
-        name, summary = record['name'].lower(), record['summary'].lower()
+        name, summary = record['name'].lower(), record['summary']
         for token in tokens:
             qtf = 0
             if token == name:
@@ -532,8 +521,8 @@ class Searcher(object):
                 n_name_matches = len(re.compile(token).findall(name))
                 qtf += self.CONTAINS_NAME_MULT * n_name_matches
             if record['summary'] is not None:
-                n_summary_matches = len(re.compile(token).findall(summary))
-                qtf += 2 * n_summary_matches
+                summary_matches = re.compile(token).findall(summary.lower())
+                qtf += 2 * len(summary_matches)
             score += qtf
         return score
 
